=======
History
=======

0.3.2 (2019-07-03)
------------------

* bugfix:
    * creo_list_dirs: return empty list if there is no folder in the directory (`issue #1`_)

* Add basic usage video on README

.. _`issue #1`: https://github.com/Zepmanbc/creopyson/issues/1


0.3.1 (2019-06-30)
------------------

* bugfixes:
    * view_list: default query name="*"


0.3.0 (2019-06-29)
------------------

* bugfixes:
    * file_set_mass_units: function param correction
    * file_list: function param correction
    * general: set active file when file is optionnal
* improvement:
    * file_open: `activate` and `display` default to True
    * dimension_set: file is optionnal


0.2.0 (2019-06-28)
------------------

* Update for Creoson 2.4.0 release. New functions:
    * parameter_set_designated
    * feature_list_group_features
    * feature_list_pattern_features
* Add missing function: 
    * feature_list_params


0.1.0 (2019-06-22)
------------------

* First release on PyPI.
